==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/GetDistributionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getDistribution.
 * @property id Identifier for the distribution. For example: `EDFDVBD632BHDS5`.
 * @property tags
 */
public data class GetDistributionPlainArgs(
    public val id: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs =
        com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs.builder()
            .id(id.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetDistributionPlainArgs].
 */
@PulumiTagMarker
public class GetDistributionPlainArgsBuilder internal constructor() {
    private var id: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Identifier for the distribution. For example: `EDFDVBD632BHDS5`.
     */
    @JvmName("vnmwrkjgfapgopiy")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.id = mapped
    }

    /**
     * @param value
     */
    @JvmName("rckhpplicnojwrkr")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values
     */
    @JvmName("motnhliqxrjdplkh")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetDistributionPlainArgs = GetDistributionPlainArgs(
        id = id ?: throw PulumiNullFieldException("id"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/GetDistributionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getDistribution.
 * @property id Identifier for the distribution. For example: `EDFDVBD632BHDS5`.
 * @property tags
 */
public data class GetDistributionPlainArgs(
    public val id: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs =
        com.pulumi.aws.cloudfront.inputs.GetDistributionPlainArgs.builder()
            .id(id.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetDistributionPlainArgs].
 */
@PulumiTagMarker
public class GetDistributionPlainArgsBuilder internal constructor() {
    private var id: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Identifier for the distribution. For example: `EDFDVBD632BHDS5`.
     */
    @JvmName("xesbwyrqqqgvdegd")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.id = mapped
    }

    /**
     * @param value
     */
    @JvmName("rxlvceurirjpagoq")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values
     */
    @JvmName("skydjhrjeycabfcu")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetDistributionPlainArgs = GetDistributionPlainArgs(
        id = id ?: throw PulumiNullFieldException("id"),
        tags = tags,
    )
}
